<?php
/**
* Plugin Name:SCIM user provisioning
* Plugin URI: http://miniorange.com
* Description: This plugin allows user provisioning from Azure AD, Okta and OneLogin to WordPress with SCIM standard.
* Version: 0.0.50
* Author: miniOrange
* License: GPL2
*/


require_once('mo-scim-user-provisioner-save.php');
require_once('mo-scim-user-provisioner-menu-settings.php');

class scim_user_provisioner_add_on {

    function __construct(){
        if(is_multisite())
            add_action( 'network_admin_menu', array($this, 'msup_scim_miniorange_menu'),11);
        else
            add_action( 'admin_menu', array( $this, 'msup_scim_miniorange_menu' ),11 );
        add_action( 'admin_init', 'msup_scim_miniorange_save_setting_user_provisioning',1 );
        add_action( 'init', 'msup_scim_user_provisioning_validate' );
        register_deactivation_hook(__FILE__, array( $this, 'msup_scim_up_deactivate'));
        remove_action( 'admin_notices', array( $this, 'msup_scim_up_success_message') );
        remove_action( 'admin_notices', array( $this, 'msup_scim_up_error_message') );
        add_action( 'admin_enqueue_scripts', array( $this, 'msup_scim_plugin_settings_script' ) );
        add_action( 'admin_enqueue_scripts', array( $this, 'msup_scim_plugin_settings_style' ) );
    }

    function msup_scim_miniorange_menu() {
        add_menu_page('SCIM User Provisioning','SCIM User Provisioning', 'administrator', 'user_provisioning','msup_scim_user_provisioning',plugin_dir_url(__FILE__) . 'images/miniorange.png');
    }

    function msup_scim_up_deactivate() {
        do_action( 'msup_scim_up_flush_cache');
        delete_site_option('msup_scim_up_message');
    }

    function msup_scim_plugin_settings_style($page) {
        wp_enqueue_style( 'msup_scim_up_admin_settings_style', plugins_url( 'includes/css/style_settings.min.css', __FILE__ ) );
    }
        
    function msup_scim_plugin_settings_script($page) {
        wp_enqueue_script('jquery');		
    }

    function msup_check_option_admin_referer($option_name){
        if(current_user_can('administrator')) {
            return check_admin_referer($option_name);
        }
        return false;
    }

    function msup_scim_up_show_success_message() {
        remove_action( 'admin_notices', array( $this, 'msup_scim_up_success_message') );
        add_action( 'admin_notices', array( $this, 'msup_scim_up_error_message') );
    }

    function msup_scim_up_show_error_message() {
        remove_action( 'admin_notices', array( $this, 'msup_scim_up_error_message') );
        add_action( 'admin_notices', array( $this, 'msup_scim_up_success_message') );
    }

    function msup_scim_up_success_message() {
        $class = "error";
        $message = get_site_option('msup_scim_up_message');
        echo "<div class='" . $class . "'> <p>" . $message . "</p></div>";
    }

    function msup_scim_up_error_message() {
        $class = "updated";
        $message = get_site_option('msup_scim_up_message');
        echo "<div class='" . $class . "'><p>" . $message . "</p></div>";
    }
}
new scim_user_provisioner_add_on;